# CoreX storage - hdfs

This package provides an implementation of the CoreX storage interface for hdfs.

## Installation
~~~bash
pip install corex-storage-hdfs
~~~

## Usage
~~~python
from corex_storage_hdfs.handler import HdfsHandler
handler = HdfsHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
